# 测试eval函数,eval()函数用来执行一个字符串表达式，并返回表达式的值。另外，可以讲字符串转换成列表或元组或字典
# s = "print('abcde')"
# eval(s)
# a = 10
# b = 20
# c = eval("a+b")
# print(c)
# dict1 = dict(a=100, b=200)
# c = eval("a+b", dict1)
# print(c)

a = "{1: 'a', 2: 'b'}"
print(type(a))
b = eval(a)
print(type(b))
print(b)


# 测试阶乘函数函数
def factorial(n):
    if n == 1:
        return 1
    else:
        return n * factorial(n - 1)


for a in range(1, 6):
    # print(a, "!=", factorial(a))
    print("{0}!={1}".format(a, factorial(a)))



# -*_coding:gb2312_*_
from distutils.core import setup

setup(
    name='liming',  # 对外我们模块的名字
    version='1.0',  # 版本号
    description='这是第一个对外发布的模块，测试哦',  # 描述
    author='gaoqi',  # 作者
    author_email='gaoqi110@163.com',
    py_modules=['liming.eval', 'liming.factorial']
)
